"""A sound editor.

Scalpel is a sound editor. It works only on Linux at this point, with
a GTK frontend and an ALSA backend.

This release improves the display speed, tidies up the UI, and makes
the space bar toggle play/stop.
"""
from constants import __version__
